Module traits
shapefile
0.8.0
Module traits
Module Items
Traits
In shapefile::
record
shapefile
::
record
Module
traits
Traits

Growable
Point
HasM
Trait to access the m value of a point
HasXY
Trait to access the x, and y values of a point
HasZ
Trait to access the z value of a point
Shrinkable
Point